@@ -1,4 +1,4 @@
-// $Id: util.c,v 1.10 2003/08/28 00:20:09 ensc Exp $    --*- c++ -*--
+// $Id: util.c,v 1.12 2004/06/16 10:35:16 ensc Exp $    --*- c++ -*--
 
 // Copyright (C) 2002,2003 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -24,13 +24,14 @@
 #include "wrappers.h"
 #include "ip-sentinel.h"
 #include "parameters.h"
+#include "fmt.h"
 
+#include <netinet/ether.h>
 #include <unistd.h>
 #include <assert.h>
 #include <sys/time.h>
 #include <arpa/inet.h>
 #include <net/if.h>
-#include <netinet/ether.h>
 #include <sys/socket.h>
 #include <sys/ioctl.h>
 #include <time.h>
@@ -41,8 +42,6 @@ void
 writeMsgTimestamp(int fd)
 {
   struct timeval                tv;
-  time_t                        aux;
-  size_t                        fill_cnt = 1;
 
   if (fd==-1) return;
   
@@ -51,68 +50,40 @@ writeMsgTimestamp(int fd)
   {
 #ifdef ENABLE_LOGGING
     char                        buffer[16];
+    time_t                      aux;
     struct tm                   tmval;
+    size_t			fill_cnt = 1;
     
     (void)localtime_r(&tv.tv_sec, &tmval);
     if (strftime(buffer, sizeof buffer, "%T", &tmval)>0) {
       (void)write(fd, buffer, strlen(buffer));
+      
+      aux  = tv.tv_usec;
+      aux |= 1; // Prevent 'aux==0' which will cause an endless-loop below
+      assert(aux>0);
+  
+      while (aux<100000) { ++fill_cnt; aux *= 10; }
+      (void)write(fd, "000000", fill_cnt-1);
+      writeUInt(fd, static_cast(unsigned int)(tv.tv_usec));
     }
     else
 #endif
     {
-      writeUInt(fd, static_cast(unsigned int)(tv.tv_sec));
-      (void)write(fd, ".", 1);
+      char			buf[64];
+      size_t			l = fmt_tai64n(buf, &tv);
+
+      write(fd, buf, l);
     }
   }
-
-  aux  = tv.tv_usec;
-  aux |= 1; // Prevent 'aux==0' which will cause an endless-loop below
-  assert(aux>0);
-  
-  while (aux<100000) { ++fill_cnt; aux *= 10; }
-  (void)write(fd, "000000", fill_cnt-1);
-  writeUInt(fd, static_cast(unsigned int)(tv.tv_usec));
-}
-
-inline static void *
-fillUIntInternal(char *buf, char *end_ptr, unsigned int val)
-{
-  do {
-      /*@-strictops@*/
-    *end_ptr-- = '0' + static_cast(char)(val%10);
-      /*@=strictops@*/
-    val   /= 10;
-  } while (val!=0 && end_ptr>=buf);
-
-  return end_ptr+1;
-}
-
-size_t
-fillUInt(char *dest, unsigned int val)
-{
-  char			buffer[32];
-  register char         *ptr = &buffer[sizeof(buffer) - 1];
-  size_t		count;
-
-  ptr = fillUIntInternal(buffer, ptr, val);
-
-  count = (buffer+sizeof(buffer))-ptr;
-  memcpy(dest, ptr, count);
-
-  return count;
 }
 
 void
 writeUInt(int fd, unsigned int val)
 {
-  char			buffer[32];
-  register char         *ptr = &buffer[sizeof(buffer) - 1];
+  char			buf[sizeof(val)*3 + 3];
+  size_t		l = fmt_uint(buf, val);
 
-  ptr = fillUIntInternal(buffer, ptr, val);
-
-    /*@-strictops@*/
-  (void)write(fd, ptr, &buffer[sizeof(buffer)] - ptr);
-    /*@=strictops@*/
+  (void)write(fd, buf, l);
 }
 
 void
